=======
Drivers
=======

Cloud management
----------------

.. cloud_driver_doc:: devstack

.. cloud_driver_doc:: devstack_systemd

.. cloud_driver_doc:: fuel

.. cloud_driver_doc:: tcpcloud


Power management
----------------

.. driver_doc:: libvirt

.. driver_doc:: ipmi


Node discover
-------------

.. driver_doc:: node_list


Service drivers
---------------

.. driver_doc:: process

.. driver_doc:: linux_service

.. driver_doc:: screen

.. driver_doc:: systemd_service

.. driver_doc:: salt_service

.. driver_doc:: pcs_service

.. driver_doc:: pcs_or_linux_service
